\name{read.svm.data}
\alias{read.svm.data}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Reading SVM Training Data from a File}
\description{
  The \code{read.svm.data} reads a training file in
  the LIBSVM data format, and is a replacement 
  of the \code{read.matrix.csr} function in \code{e1071}.

  In the non-free \code{rpudplus} add-on, the method redirects to
  a native C++ implementation with enhanced robustness and performance. 
  
  This method is not supported in the free \code{rpud} package.
}
\usage{
read.svm.data(file, fac = TRUE, sparse = TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{file}{The path name of the file in LIBSVM training data format.}
  \item{fac}{If \code{TRUE} and y-values are stored in the file, the
    values are interpreted as factor levels.}
  \item{sparse}{If \code{TRUE}, the x-values are loaded into a \code{matrix.csr}
    object provided by the \code{SparseM} package. 
    If \code{FALSE}, the x-values are loaded into a data matrix instead.}
}
\value{
  The method returns a list with two components:
  \item{x}{object of class \code{matrix.csr} or a data matrix, depending on
    the value of \code{sparse}.}
  \item{y}{vector of numeric values or factor levels, depending on 
    the value of \code{fac}.}
}
\author{
  Chi Yau (based on R doc of \code{read.matrix.csr} in \code{e1071} by David Meyer)\cr
  \email{chi.yau@r-tutor.com}
}
\seealso{\code{\link[SparseM]{matrix.csr}}}

\examples{
\dontrun{

library(rpud)
library(SparseM)

filepath <- file.path(.path.package(package="rpud"), "runit/data/heart_scale")
hs <- read.svm.data(filepath, fac=TRUE)

x <- hs$x
y <- hs$y
    
model <- rpusvm(x, y)
summary(model)

}}
\keyword{IO}% at least one, from doc/KEYWORDS
