\name{rpudl}
\alias{rpudl}
\alias{rpudl.default}
\concept{deep learning}

\title{
RPUDL Model of Deep Learning
}

\description{
Creates an S3 object that represents a \code{RPUDL} model.
It contains the necessary information for model training afterwards.
}

\details{
An \code{RPUDL} model is described in Google Protocol Buffers (\code{protobuf}) 
message format. The .proto file that defines the message type
is posted online at http://www.r-tutor.com.
The \code{RPUDL} runtime supports save/resume incremental training, 
and autoencoders for pre-training.
It uses \code{LMDB} database as native data input format. 
}

\usage{
\method{rpudl}{default}(
    model.file, 
    data.source, 
    \dots, 
    log.level = 1
    )
}

\arguments{
  \item{model.file}{path location of a text file that defines
        an \code{RPUDL} model in the code{protobuf} text format}
  \item{data.source}{a \code{RPUDL} object that represents
        the training and testing data}
  \item{\dots}{further arguments to be passed to or from methods}
  \item{log.level}{level of the method output (0 = silent, 
        1 = basic output, 2 = detailed output)} 
}

\value{
  An S3 \code{rpudl} object that represents an \code{RPUDL} model, containing:
  \item{model.file}{path location of the \code{RPUDL} model in \code{protobuf} text format}
  \item{model.spec}{text description of the \code{RPUDL} model file in \code{protobuf} text format}
  \item{data.format}{format of the data set}
  \item{data.dir}{path location of the data set}
  \item{data.shape}{the width and height of each data item}
  \item{data.channels}{number of channels of each data item}
  \item{train.data}{name of the training \code{LMDB} database}
  \item{test.data}{name of the testing \code{LMDB} database}
  \item{param.data}{parametric values of individual layers in the model}
  \item{mean.data}{mean value of the training data items}
  \item{model.classes}{number of classification classes of the model}
  \item{learning.rate}{manual override of the learning rate, ignored if zero or negative}
  \item{cost.log}{accumulative log of the model cost after each training iteration}
  \item{cost}{model cost evaluated against the test data}
  \item{loss}{prediction error ratio evaluated against the test data}
}

\author{
  Chi Yau\cr
  \email{chi.yau@r-tutor.com}
}

\seealso{
  rpudlCreateDataSource,\cr
  rpudlTrain,\cr
  rpudlPretrain,\cr
  predict.rpudl
}

\examples{
\dontrun{
# create data source
ds <- rpudlCreateDataSource(
        data.format="lmdb",
        data.dir="data/mnist",
        train.data="mnist-official-data_train_lmdb",
        test.data="mnist-official-data_test_lmdb",
        data.shape=c(28, 28)
)

# create model
model <- rpudl(
        "mnist_mpl_lenet.prototxt",
        data.source=ds
)   

# train model
model <- rpudlTrain(model, batch=100, iter=1000)
}}

\keyword{misc}

